==> galaxeus_lib-0.0.56.tar.gz: lib/galaxeus_lib.dart <==
// ignore_for_file: unnecessary_brace_in_string_interps, non_constant_identifier_names

library galaxeus_lib;

import 'dart:math';

import 'package:galaxeus_lib/extension/extension.dart';
import 'package:universal_io/io.dart';
export 'package:http/http.dart';

export 'src/json_each.dart';
export "json_to_script_dart/json_to_script.dart";
export 'src/json_to_dart.dart';
export "src/json_to_isar.dart";
export "src/json_to_message.dart";
export 'src/json_to_update.dart';
export 'src/production.dart';
export "extension/extension.dart";

export 'extension/tcp.dart';
export 'args/args.dart';
export 'captcha/captcha.dart';
export "crypto/crypto.dart";
export 'src/device_id.dart';
export 'event_emitter/event_emitter.dart';
export 'fetch/fetch.dart';
export 'tcp/tcp_client.dart' if (dart.library.html) 'tcp/tcp_client_web.dart';

export 'tcp/tcp_server.dart';
export 'src/utils.dart';
export 'websocket/websocket_client.dart';

/// getRandom uuid for parameters @extra
String getUuid(int length, {String? text}) {
  var ch = '0123456789abcdefghijklmnopqrstuvwxyz';
  if (text != null && text.isNotEmpty) {
    ch = text;
  }
  Random r = Random();
  return String.fromCharCodes(Iterable.generate(length, (_) => ch.codeUnitAt(r.nextInt(ch.length))));
}

String generateUuid(
  int length, {
  String text = "0123456789abcdefghijklmnopqrstuvwxyz",
}) {
  Random random = Random();
  return List.generate(length, (index) {
    String data_text = text[random.nextInt(text.length)];
    List<bool> true_false_data = [
      true,
      false,
    ];
    if (true_false_data[random.nextInt(true_false_data.length)]) {
      return data_text.toUpperCase();
    } else {
      return data_text;
    }
  }).join("");
}

T getRandomElement<T>(List<T> list) {
  final random = Random();
  var i = random.nextInt(list.length);
  return list[i];
}

class JsonDataScript {
  String className;
  List<String> datas;
  bool is_isar;
  JsonDataScript({
    required this.className,
    required this.datas,
    this.is_isar = false,
  });
  String get first {
    return datas.first;
  }

  String get last {
    return datas.last;
  }

  String get first_name {
    return "${className.snakeCaseClass().toLowerCase()}.dart";
  }

  String get last_name {
    return "${className.snakeCaseClass().toLowerCase()}.g.dart";
  }

  Future<Directory> saveToFile(Directory output) async {
    if (!output.existsSync()) {
      await output.create(recursive: true);
    }

    String output_path = output.path;
    String output_first_name = output_path;
    String output_last_name = output_path;
    if (output_path[output_path.length - 1] == "/") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else if (output_path[output_path.length - 1] == r"\") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else {
      if (Platform.isWindows) {
        output_first_name = "${output_path}\\${first_name}";
        output_last_name = "${output_path}\\${last_name}";
      } else {
        output_first_name = "${output_path}/${first_name}";
        output_last_name = "${output_path}/${last_name}";
      }
    }
    await File(output_first_name).writeAsString(first);
    if (is_isar) {
      await File(output_last_name).writeAsString(last);
    }
    return output;
  }
}

==> galaxeus_lib-0.0.62.tar.gz: lib/galaxeus_lib.dart <==
// ignore_for_file: unnecessary_brace_in_string_interps, non_constant_identifier_names

library galaxeus_lib;

import 'dart:math';

import 'package:galaxeus_lib/extension/extension.dart';
import 'package:universal_io/io.dart';
export 'package:http/http.dart';

export "dart/dart.dart";
export 'src/json_each.dart';
export "json_to_script_dart/json_to_script.dart";
export 'src/json_to_dart.dart';
export "src/json_to_isar.dart";
export "src/json_to_message.dart";
export 'src/json_to_update.dart';
export 'src/production.dart';
export "extension/extension.dart";

export 'extension/tcp.dart';
export 'args/args.dart';
export 'captcha/captcha.dart';
export "crypto/crypto.dart";
export 'src/device_id.dart';
export 'event_emitter/event_emitter.dart';
export 'fetch/fetch.dart';
export 'tcp/tcp_client.dart' if (dart.library.html) 'tcp/tcp_client_web.dart';

export 'tcp/tcp_server.dart';
export 'src/utils.dart';
export 'websocket/websocket_client.dart';

/// getRandom uuid for parameters @extra
String getUuid(int length, {String? text}) {
  var ch = '0123456789abcdefghijklmnopqrstuvwxyz';
  if (text != null && text.isNotEmpty) {
    ch = text;
  }
  Random r = Random();
  return String.fromCharCodes(
      Iterable.generate(length, (_) => ch.codeUnitAt(r.nextInt(ch.length))));
}

String generateUuid(
  int length, {
  String text = "0123456789abcdefghijklmnopqrstuvwxyz",
}) {
  Random random = Random();
  return List.generate(length, (index) {
    String data_text = text[random.nextInt(text.length)];
    List<bool> true_false_data = [
      true,
      false,
    ];
    if (true_false_data[random.nextInt(true_false_data.length)]) {
      return data_text.toUpperCase();
    } else {
      return data_text;
    }
  }).join("");
}

T getRandomElement<T>(List<T> list) {
  final random = Random();
  var i = random.nextInt(list.length);
  return list[i];
}

class JsonDataScript {
  String className;
  List<String> datas;
  bool is_isar;
  JsonDataScript({
    required this.className,
    required this.datas,
    this.is_isar = false,
  });
  String get first {
    return datas.first;
  }

  String get last {
    return datas.last;
  }

  String get first_name {
    return "${className.snakeCaseClass().toLowerCase()}.dart";
  }

  String get last_name {
    return "${className.snakeCaseClass().toLowerCase()}.g.dart";
  }

  Future<Directory> saveToFile(Directory output) async {
    if (!output.existsSync()) {
      await output.create(recursive: true);
    }

    String output_path = output.path;
    String output_first_name = output_path;
    String output_last_name = output_path;
    if (output_path[output_path.length - 1] == "/") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else if (output_path[output_path.length - 1] == r"\") {
      output_first_name = "${output_path}${first_name}";
      output_last_name = "${output_path}${last_name}";
    } else {
      if (Platform.isWindows) {
        output_first_name = "${output_path}\\${first_name}";
        output_last_name = "${output_path}\\${last_name}";
      } else {
        output_first_name = "${output_path}/${first_name}";
        output_last_name = "${output_path}/${last_name}";
      }
    }
    await File(output_first_name).writeAsString(first);
    if (is_isar) {
      await File(output_last_name).writeAsString(last);
    }
    return output;
  }
}
